Index: trunk/MagicSoft/Mars/mtemp/mifae/Changelog
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/Changelog	(revision 4140)
+++ trunk/MagicSoft/Mars/mtemp/mifae/Changelog	(revision 4141)
@@ -20,11 +20,13 @@
 
  2004/05/24 Javier Rico
-   * library/MDisplay.[h,cc], library/MHillasDisplay.[h,cc]
-     programs/makeHillas.cc, programs/makehillas.datacard
+   * library/MDisplay.[h,cc], programs/makeHillas.cc, 
+     programs/makehillas.datacard
      - Add possibility to save a ps file
      - Update documentation
 	
-   * library/MHillasDisplay	
+   * library/MHillasDisplay[h.cc]
      - correct minor axis paint
+     - include MNewImagePar dumping
+     - update documentation
 	
  2004/05/21 Oscar Blanch
Index: trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc	(revision 4140)
+++ trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.cc	(revision 4141)
@@ -56,4 +56,5 @@
 #include "MGeomCam.h"
 #include "MHillas.h"
+#include "MNewImagePar.h"
 #include "MSrcPosCam.h"
 
@@ -71,5 +72,5 @@
 //
 MHillasDisplay::MHillasDisplay(MCerPhotEvt* event, MGeomCam* geom, Int_t type, const char* name, const char* title) 
-  :  MDisplay(event,geom,type), fHillas(NULL), fSrcPos(NULL)
+  :  MDisplay(event,geom,type), fHillas(NULL), fNewImage(NULL), fSrcPos(NULL)
 {
   fName  = name  ? name  : gsDefName.Data();
@@ -97,4 +98,10 @@
     }
 
+  // Look for the MNewImagePar container  
+  if(!fNewImage)
+    fNewImage = (MNewImagePar*)pList->FindObject(AddSerialNumber("MNewImagePar"), "MNewImagePar");
+  if(!fNewImage)
+    *fLog << warn << "MHillasDisplay::PreProcess Warning: MNewImagePar object not found" << endl;
+
   // Look for the MHillas container  
   if(!fSrcPos)
@@ -114,4 +121,7 @@
   if(fHillas && GetPauseMode())
     fHillas->Print();
+  if(fNewImage && GetPauseMode())
+    fNewImage->Print();
+      
    
   // draw the event
Index: trunk/MagicSoft/Mars/mtemp/mifae/programs/makeHillas.cc
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/programs/makeHillas.cc	(revision 4140)
+++ trunk/MagicSoft/Mars/mtemp/mifae/programs/makeHillas.cc	(revision 4141)
@@ -31,4 +31,5 @@
 #include "MPedPhotCalc.h"
 #include "MHillas.h"
+#include "MNewImagePar.h"
 #include "MRawRunHeader.h"
 #include "MSrcPosCam.h"
@@ -227,4 +228,5 @@
   // containers 
   MHillas       hillas;
+  MNewImagePar  newimagepar;
   MSrcPosCam    source;
   MRawRunHeader runhead;
@@ -259,4 +261,5 @@
   plist4.AddToList(&source);
   plist4.AddToList(&hillas);
+  plist4.AddToList(&newimagepar);
   plist4.AddToList(&runhead);
 

Index: trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h
===================================================================
--- trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h	(revision 4140)
+++ trunk/MagicSoft/Mars/mtemp/mifae/library/MHillasDisplay.h	(revision 4141)
@@ -10,10 +10,12 @@
 class MGeomCam;
 class MHillas;
+class MNewImagePar;
 
 class MHillasDisplay : public MDisplay
 {
  private:
-  MHillas* fHillas;    // pointer to container with the hillas parameters
-  MSrcPosCam* fSrcPos; // pointer to the source position in camera
+  MHillas*      fHillas;    // pointer to container with the hillas parameters
+  MNewImagePar* fNewImage;  // pointer to container with the new image parameters
+  MSrcPosCam*   fSrcPos;     // pointer to the source position in camera
 
   virtual Int_t PreProcess(MParList *plist);